# Youtube-Renderer-Pypi-Package 

This repository contains the source code and documentation for the Youtube Renderer Python package,which is available on Pypi. The YouTube Renderer is a powerful tool for rendering any youtube videos and any web page over the Jupyter/Colab Notebook.

# How to run? 

1. Create a virtual environment 
   ```bash
   conda create -n renderer python=3.11 -y 
   ``` 

2. Activate the virtual environment 
   ```bash 
   conda activate renderer 
   ``` 

3. Install the required package 
   ```bash 
   pip install -r requirement_dev.txt
   ```